/*
 * Copyright (C) 2007-2019 Artima, Inc. All rights reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Example code from:
 *
 * Programming in Scala, Fifth Edition
 * by Martin Odersky, Lex Spoon, Bill Venners, and Frank Sommers
 *
 * http://booksites.artima.com/programming_in_scala_5ed
 */

package org.stairwaybook.mutableobjects

object Ex7 {
  import scala.compiletime.uninitialized
  
  class Thermometer:
  
    var celsius: Float = uninitialized
  
    def fahrenheit = celsius * 9 / 5 + 32
    def fahrenheit_=(f: Float) =
      celsius = (f - 32) * 5 / 9
  
    override def toString = s"${fahrenheit}F/${celsius}C"

  def main(args: Array[String]): Unit = {
    val t = new Thermometer

    t.celsius = 100
    println("t [" + (t) + "]")

    t.fahrenheit = -40
    println("t [" + (t) + "]")
  }
}
